@@ -58,7 +58,7 @@ def from_config(ctx, config_file, verbose):
 
     # initialize loggers
     init_mult(name, config.logdir, modules=[__name__, 'reV.config',
-                                            'reV.utilities'],
+                                            'reV.utilities', 'rex.utilities'],
               verbose=verbose)
 
     # Initial log statements
